
# cadqueryhelper
CadQuery Helper library.<br />
Code for shape primitives, looping groups of shapes, hinges, and various wave operations.

![](https://raw.githubusercontent.com/medicationforall/cadqueryhelper/refs/heads/main/documentation/image/shape/43.png)

## Links
* [README.md](https://github.com/medicationforall/cadqueryhelper)
* [Documentation](https://github.com/medicationforall/cadqueryhelper/blob/main/documentation/documentation.md)
* [Changelog](https://github.com/medicationforall/cadqueryhelper/blob/main/changes.md)


## Dependencies
* [CadQuery](https://github.com/CadQuery/cadquery)
  